add_code: Add code Append a new unit record to the existing data frame

Description Usage Arguments

View source: R/utils.R

Description

Add code Append a new unit record to the existing data frame

Usage

1
add_code(codes_df, new_code, new_code_desc, codes_df_path)

Arguments

codes_df

Existing codes data frame

new_code

text name of a new code (single name only)

new_code_desc

text description of the code

codes_df_path

full path to the codes data frame


qcoderproject/qcoder documentation built on May 20, 2019, 7:36 a.m.