add_discovered_code: Update codes data frame Add discovered codes to the codes...

Description Usage Arguments

View source: R/parse_qcodes.R

Description

Update codes data frame Add discovered codes to the codes data frame

Usage

1
2
add_discovered_code(codes_list = "", code_data_frame = NULL,
  codes_df_path = "")

Arguments

codes_list

A list of codes (usually from a coded document)

code_data_frame

Existing data frame of QCODE codes

codes_df_path

The path where the updated code data frame should be saved


qcoderproject/qcoder documentation built on May 20, 2019, 7:36 a.m.