add_new_documents: Add new documents Adds new document or documents to an...

Description Usage Arguments

View source: R/read_in_files.R

Description

Add new documents Adds new document or documents to an existing documents data frame.

Usage

1
add_new_documents(files, docs_df_path = "", file_path = "")

Arguments

files

file tibble produced by ShinyFiles

docs_df_path

Existing data frame of text documents

file_path

Full path to the data set of documents including trailing slash


qcoderproject/qcoder documentation built on May 20, 2019, 7:36 a.m.