add_unit: Add unit Append a new unit record to the existing data frame

Description Usage Arguments

View source: R/utils.R

Description

Add unit Append a new unit record to the existing data frame

Usage

1
add_unit(units_df, new_unit, units_df_path)

Arguments

units_df

Existing units data frame

new_unit

text name of a new unit (single name only)

units_df_path

full path to the units data frame


qcoderproject/qcoder documentation built on May 20, 2019, 7:36 a.m.