View source: R/read_in_files.R
Used to create a codes data frame with no data but that can have data added.
1 2 | create_empty_code_file(data_frame_name = "qcoder_codes", codes_df_path = "",
project_path = "", file_path = "data_frames", project_name = "")
|
data_frame_name |
Name of the data frame to be created |
codes_df_path |
The full path to the codes data frame |
project_path |
The full path to the project folder |
file_path |
Path to the file location to be used (under project root). defaults to "data_frames". |
project_name |
Name of the project that the codes are associated with |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.