create_qcoder_project: Create a standard set of folders for a QCoder project

Description Usage Arguments Examples

View source: R/utils.R

Description

Create a standard set of folders for a QCoder project

Usage

1

Arguments

project_name

A string project name to be located in the current working directory or a path to a project folder.

sample

Logical that indicates that the sample data should be copied to the project.

Examples

1
create_qcoder_project(project_name = "my_qcoder_project")

qcoderproject/qcoder documentation built on May 20, 2019, 7:36 a.m.