View source: R/read_in_files.R
Define a many to many unit to document map
1 2 | create_unit_doc_file(file_path = "data_frames",
data_frame_name = "unit_document_map", project_name)
|
file_path |
Path to store data frame on. |
data_frame_name |
Name of the data frame that will contain the map |
project_name |
Name of the project, if it exists |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.