get_codes: Extract codes from text Take coded text and extract the...

Description Usage Arguments

View source: R/parse_qcodes.R

Description

Extract codes from text Take coded text and extract the codes, assuming they are correctly formatted.

Usage

1
get_codes(doc_text)

Arguments

doc_text

The text data for a single document


qcoderproject/qcoder documentation built on May 20, 2019, 7:36 a.m.