import_project_data: Read data into a project Convenience method to read raw data...

Description Usage Arguments

View source: R/read_in_files.R

Description

Read data into a project Convenience method to read raw data from standard locations and using standard names in a project folder structure.

Usage

1
import_project_data(project_name)

Arguments

project_name

The project name. This should represent the folder holding the project.


qcoderproject/qcoder documentation built on May 20, 2019, 7:36 a.m.