read_raw_data: Create a data frame of documents

Description Usage Arguments Examples

View source: R/read_in_files.R

Description

Create a data frame of documents

Usage

1
2
3
read_raw_data(folder_path = "/documents/",
  data_frame_name = "qcoder_documents", project_name = NULL,
  docs_df_path = "", project_path = "")

Arguments

folder_path

path to a folder contain text files to be analyzed.

data_frame_name

The name of the RDS file that the data frame will be stored in.

project_name

Name of the Qcoder project

docs_df_path

Full path to the docs data frame.

project_path

Full path to the project folder.

Examples

1
2
3
4
5
6
 ## Not run: 
fp <-"/documents/"
dfn <- "testdata"
read_raw_data(fp, dfn, "")

## End(Not run)

qcoderproject/qcoder documentation built on May 20, 2019, 7:36 a.m.