update_links: Update document to unit links Saves or updates the links...

Description Usage Arguments

View source: R/utils.R

Description

Update document to unit links Saves or updates the links between observation units and documents

Usage

1
2
update_links(checked = "", docs_df_path = "", this_doc_path = "",
  units_docs_path = "")

Arguments

checked

vector of new or updated links

docs_df_path

full path to document dataset

this_doc_path

value of doc_path for the document

units_docs_path

full path of the data frame of unit to docs links


qcoderproject/qcoder documentation built on May 20, 2019, 7:36 a.m.