View source: R/read_in_files.R
Add new documents Adds new document or documents to an existing documents data frame.
1 | add_new_documents(files, docs_df_path = "", file_path = "")
|
files |
file tibble produced by ShinyFiles |
docs_df_path |
Existing data frame of text documents |
file_path |
Full path to the data set of documents including trailing slash |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.