View source: R/read_in_files.R
Read data into a project Convenience method to read raw data from standard locations and using standard names in a project folder structure.
1 | import_project_data(project_name)
|
project_name |
The project name. This should represent the folder holding the project. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.