Description Usage Arguments Examples
View source: R/read_in_files.R
Create a file of codes from csv file Use this is you have a spreadsheet of codes already created.
1 2 | read_code_data(file_path = "codes/codes.csv", codes_df_path = "",
data_frame_name = "qcoder_codes", project_name, project_path = "")
|
file_path |
Path to a file containing code data in csv. |
codes_df_path |
Full path to the codes data frame. |
data_frame_name |
The name of the RDS file that the data frame will be stored in. |
project_name |
Name of the project, which matches folder name |
project_path |
Full path to the project folder |
1 2 3 4 5 6 | ## Not run:
fp <-"inst/example_codes/"
dfn <- "test_codes"
read_code_data(fp, dfn)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.