Description Usage Arguments Examples
View source: R/read_in_files.R
Create a data frame of documents
1 2 3 | read_raw_data(folder_path = "/documents/",
data_frame_name = "qcoder_documents", project_name = NULL,
docs_df_path = "", project_path = "")
|
folder_path |
path to a folder contain text files to be analyzed. |
data_frame_name |
The name of the RDS file that the data frame will be stored in. |
project_name |
Name of the Qcoder project |
docs_df_path |
Full path to the docs data frame. |
project_path |
Full path to the project folder. |
1 2 3 4 5 6 | ## Not run:
fp <-"/documents/"
dfn <- "testdata"
read_raw_data(fp, dfn, "")
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.