Description Usage Arguments Examples
View source: R/read_in_files.R
Create a data frame of units from csv file Use this is you have a spreadsheet of units already created.
1 2 | read_unit_data(file_path = "units.csv", data_frame_name = "qcoder_units",
project_name, project_path = "", units_df_path = "")
|
file_path |
path to a file containing unit data in csv. |
data_frame_name |
The name of the RDS file that the data frame will be stored in. |
project_name |
Name of project if available |
project_path |
Full path to the project folder. |
units_df_path |
Full path to the units data frame. |
1 2 3 4 5 6 | ## Not run:
fp <-"units/units.csv"
dfn <- "my_units"
read_unit_data(fp, dfn)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.