Description Usage Arguments Examples
View source: R/read_in_files.R
Create a data frame of unit to document links from csv file Use this is you have a spreadsheet already created.
1 2 3 | read_unit_document_map_data(file_path = "unit_document_map.csv",
data_frame_name = "qcoder_unit_document_map", project_name,
project_path = "", units_docs_path = "")
|
file_path |
path to a file containing unit document map data in csv. |
data_frame_name |
The name of the RDS file that the data frame will be stored in. |
project_name |
Name of project if available |
project_path |
Full path to the project folder |
units_docs_path |
Full path to the documents data frame. |
1 2 3 4 5 6 | ## Not run:
fp <-"units/units.csv"
dfn <- "my_units"
read_unit_data(fp, dfn)
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.