Update document to unit links Saves or updates the links between observation units and documents
1 2 | update_links(checked = "", docs_df_path = "", this_doc_path = "",
units_docs_path = "")
|
checked |
vector of new or updated links |
docs_df_path |
full path to document dataset |
this_doc_path |
value of doc_path for the document |
units_docs_path |
full path of the data frame of unit to docs links |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.